@@ -1,5 +1,8 @@
 ridge.cv<-
 function(X,y,lambda=NULL,scale=TRUE,k=10,plot.it=FALSE){
+        if (is.vector(X)==TRUE){
+            X<-matrix(X,ncol=1)
+        }
     if (is.null(lambda)==TRUE){
         ss<-seq(-10,-1,length=1000)
         ss<-10^ss
@@ -16,8 +19,14 @@ function(X,y,lambda=NULL,scale=TRUE,k=10,plot.it=FALSE){
         ytrain=y[-omit]
         Xtest=X[omit,,drop=FALSE]
         ytest=y[omit]
+        if ((is.vector(X)==TRUE)| (ncol(X)==1)){
+              xtrain<-as.vector(Xtrain)
+              coef.ll<-lm.ridge.univariate(xtrain,ytrain,lambda=lambda,scale=scale)
+        }
+        else{
         ll<-lm.ridge(ytrain~Xtrain,scale=scale,lambda=lambda)
         coef.ll<-coef(ll)
+    }
         res<-matrix(,length(ytest),length(lambda))
         pred<-t(matrix(coef.ll[,1],nrow=length(lambda),ncol=length(ytest))) + Xtest%*%t(coef.ll[,-1])
         res<-pred-matrix(ytest,nrow=length(ytest),ncol=length(lambda))
@@ -29,8 +38,15 @@ function(X,y,lambda=NULL,scale=TRUE,k=10,plot.it=FALSE){
     if (plot.it==TRUE){
         plot(lambda,cv,type="l")
     }
+    if ((is.vector(X)==TRUE)| (ncol(X)==1)){
+      x<-as.vector(X)
+     coefficients<- as.vector(lm.ridge.univariate(x,y,scale=scale,lambda=lambda.opt))
+      
+    }
+    else{
     rr<-lm.ridge(y~X,scale=scale,lambda=lambda.opt)
     coefficients<-coef(rr)
+    }
     intercept<-coefficients[1]
     coefficients<-coefficients[-1]
     return(list(intercept=intercept,coefficients=coefficients,lambda.opt=lambda.opt))
